flintqs: Multi-polynomial quadratic sieve for integer factorization
===================================================================

Description
-----------

This is William Hart's GPL'd highly optimized multi-polynomial quadratic
sieve for integer factorization:

   http://www.friedspace.com/QS/

See also http://www.maths.warwick.ac.uk/~masfaw/preprint.html

See also the repository: https://github.com/sagemath/FlintQS
